#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-FFvLcMCagmy3KgQFZTb3tg
key:                  openssl-streams-1.2.3.0-FFvLcMCagmy3KgQFZTb3tg
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  0369a9d0945054d55738d7412614fb43
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-8.10.5/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/openssl-streams-1.2.3.0
hs-libraries:         HSopenssl-streams-1.2.3.0-FFvLcMCagmy3KgQFZTb3tg
depends:
    HsOpenSSL-0.11.7-1hYph9hRA0GEWAM7ExWAT7 base-4.14.2.0
    bytestring-0.10.12.0 io-streams-1.5.2.1-FqhAw5DaL3n9TnjsO4t6Wn
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

